ExFdbmonitor.Fdbcli (ex_fdbmonitor v0.2.1)
View SourceThis module provides functions for executing fdbcli commands.
Options
All exec variants accept an optional opts keyword list:
:timeout- maximum time in milliseconds to wait for fdbcli to complete. When set, the OS process is killed if it does not finish within the allotted time.:stderr- whether to capture stderr (defaulttrue). Set tofalsewhen only stdout is needed, e.g. when parsing structured output like JSON.
Summary
Functions
Run a fdbcli command against the current node's cluster file.
Run a fdbcli command against the given cluster file.
Run a fdbcli command against the given cluster file with options.